@@ -9,10 +9,10 @@
 #include "mainContext.h"
 
 #include <KAboutData>
-#include <KActionCollection>
 #include <KIO/Global> // upUrl
 #include <KLocalizedString>
 
+#include <QBindable>
 #include <QDir>
 #include <QFileDialog>
 #include <QQmlApplicationEngine>
@@ -23,10 +23,10 @@
 #include "define.h"
 #include "dropperItem.h"
 #include "fileModel.h"
-#include "historyAction.h"
 #include "radialMap/map.h"
 #include "radialMap/radialMap.h"
 #include "scan.h"
+#include "windowThemer.h"
 
 using namespace Qt::StringLiterals;
 
@@ -48,16 +48,12 @@ public:
 
 MainContext::MainContext(QObject *parent)
     : QObject(parent)
-    , m_histories(nullptr)
     , m_manager(new ScanManager(this))
 {
     Config::instance()->read();
 
     auto engine = new QQmlApplicationEngine(this);
 
-    setupActions(engine);
-    connect(m_manager, &ScanManager::aborted, m_histories, &HistoryCollection::stop);
-
     static auto l10nContext = new KLocalizedContext(engine);
     l10nContext->setTranslationDomain(QStringLiteral(TRANSLATION_DOMAIN));
     engine->rootContext()->setContextObject(l10nContext);
@@ -67,6 +63,7 @@ MainContext::MainContext(QObject *parent)
     auto about = new About(this);
     qRegisterMetaType<size_t>("size_t");
     qmlRegisterType<DropperItem>("org.kde.filelight", 1, 0, "DropperItem");
+    qmlRegisterType<WindowThemer>("org.kde.filelight", 1, 0, "WindowThemer");
     qmlRegisterSingletonInstance("org.kde.filelight", 1, 0, "About", about);
     qmlRegisterSingletonInstance("org.kde.filelight", 1, 0, "ScanManager", m_manager);
     qmlRegisterSingletonInstance("org.kde.filelight", 1, 0, "MainContext", this);
@@ -98,11 +95,13 @@ MainContext::MainContext(QObject *parent)
         }
     });
 
+    connect(m_manager, &ScanManager::aborted, fileModel, [fileModel]() {
+        fileModel->setTree({});
+    });
+
     connect(RadialMap::Map::instance(), &RadialMap::Map::signatureChanged, fileModel, [fileModel]() {
         const auto tree = RadialMap::Map::instance()->root();
-        if (tree) {
-            fileModel->setTree(tree);
-        }
+        fileModel->setTree(tree);
     });
 
     engine->setInitialProperties({
@@ -130,41 +129,6 @@ void MainContext::scan(const QUrl &u)
     slotScanUrl(u);
 }
 
-void MainContext::setupActions(QQmlApplicationEngine *engine) // singleton function
-{
-    // Only here to satisfy the HistoryCollection. TODO: revise historycollection
-    auto ac = new KActionCollection(this, QStringLiteral("dummycollection"));
-
-    m_histories = new HistoryCollection(ac, this);
-
-    for (const auto &name : {QStringLiteral("go_back"), QStringLiteral("go_forward")}) {
-        // Synthesize actions
-        auto action = ac->action(name);
-        Q_ASSERT(action);
-
-        QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/ui/Action.qml")));
-        QObject *qmlAction = component.createWithInitialProperties({
-            {u"icon.name"_s, action->icon().name()},
-            {u"text"_s, action->text()},
-            {u"enabled"_s, action->isEnabled()},
-            {u"shortcut"_s, action->shortcut()},
-        });
-        if (!qmlAction) {
-            qWarning() << "Failed to load component:" << component.errorString();
-            Q_ASSERT(qmlAction);
-            continue;
-        }
-        connect(qmlAction, SIGNAL(triggered()), action, SIGNAL(triggered()));
-        connect(action, &QAction::changed, qmlAction, [action, qmlAction] {
-            qmlAction->setProperty("enabled", action->isEnabled());
-        });
-
-        addHistoryAction(qmlAction);
-    }
-
-    connect(m_histories, &HistoryCollection::activated, this, &MainContext::slotScanUrl);
-}
-
 void MainContext::slotScanFolder()
 {
     slotScanUrl(QFileDialog::getExistingDirectoryUrl(nullptr, i18n("Select Folder to Scan"), url()));
@@ -202,7 +166,6 @@ bool MainContext::slotScanUrl(const QUrl &url)
     const QUrl oldUrl = this->url();
 
     if (openUrl(url)) {
-        m_histories->push(oldUrl);
         return true;
     }
     return false;
@@ -287,12 +250,6 @@ bool MainContext::start(const QUrl &url) const
     return m_manager->start(url);
 }
 
-void MainContext::addHistoryAction(QObject *action)
-{
-    m_historyActions.append(action);
-    Q_EMIT historyActionsChanged();
-}
-
 } // namespace Filelight
 
 #include "mainContext.moc"
